HelpScoutBeaconApi class
Help Scout Beacon API
Constructors
- HelpScoutBeaconApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for HelpScoutBeaconApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> - Logs the current Beacon user out and clears out their information from local storage.
-
identify(
{required HSBeaconUser beaconUser}) → Future< void> - Signs in with a Beacon user. This gives Beacon access to the user’s name, email address, and signature.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
{required HSBeaconSettings settings, HSBeaconRoute route = HSBeaconRoute.ask, String? parameter}) → Future< void> - Opens the Beacon SDK from a specific view controller. The Beacon view controller will be presented as a modal.
-
prefillContactForm(
String? subject, String? message, List< String> ? attachments) → Future<void> -
setup(
{required HSBeaconSettings settings}) → Future< void> - Initialize the beacon with a beaconId and optional settings
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>